@@ -12,10 +12,26 @@ Usage::
 import sys
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_batch.literals import (
+    ArrayJobDependency,
+    AssignPublicIp,
+    CEState,
+    CEStatus,
+    CEType,
+    CRAllocationStrategy,
+    CRType,
+    DeviceCgroupPermission,
+    EFSAuthorizationConfigIAM,
+    EFSTransitEncryption,
+    JobStatus,
+    JQState,
+    JQStatus,
+    LogDriver,
+    PlatformCapability,
+    ResourceType,
+    RetryAction,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -125,9 +141,9 @@ _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
     "_OptionalComputeEnvironmentDetailTypeDef",
     {
         "tags": Dict[str, str],
-        "type": Literal["MANAGED", "UNMANAGED"],
-        "state": Literal["ENABLED", "DISABLED"],
-        "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
+        "type": CEType,
+        "state": CEState,
+        "status": CEStatus,
         "statusReason": str,
         "computeResources": "ComputeResourceTypeDef",
         "serviceRole": str,
@@ -147,19 +163,12 @@ ComputeEnvironmentOrderTypeDef = TypedDict(
 )
 
 _RequiredComputeResourceTypeDef = TypedDict(
-    "_RequiredComputeResourceTypeDef",
-    {
-        "type": Literal["EC2", "SPOT", "FARGATE", "FARGATE_SPOT"],
-        "maxvCpus": int,
-        "subnets": List[str],
-    },
+    "_RequiredComputeResourceTypeDef", {"type": CRType, "maxvCpus": int, "subnets": List[str]}
 )
 _OptionalComputeResourceTypeDef = TypedDict(
     "_OptionalComputeResourceTypeDef",
     {
-        "allocationStrategy": Literal[
-            "BEST_FIT", "BEST_FIT_PROGRESSIVE", "SPOT_CAPACITY_OPTIMIZED"
-        ],
+        "allocationStrategy": CRAllocationStrategy,
         "minvCpus": int,
         "desiredvCpus": int,
         "instanceTypes": List[str],
@@ -262,7 +271,7 @@ ContainerSummaryTypeDef = TypedDict(
 _RequiredDeviceTypeDef = TypedDict("_RequiredDeviceTypeDef", {"hostPath": str})
 _OptionalDeviceTypeDef = TypedDict(
     "_OptionalDeviceTypeDef",
-    {"containerPath": str, "permissions": List[Literal["READ", "WRITE", "MKNOD"]]},
+    {"containerPath": str, "permissions": List[DeviceCgroupPermission]},
     total=False,
 )
 
@@ -273,7 +282,7 @@ class DeviceTypeDef(_RequiredDeviceTypeDef, _OptionalDeviceTypeDef):
 
 EFSAuthorizationConfigTypeDef = TypedDict(
     "EFSAuthorizationConfigTypeDef",
-    {"accessPointId": str, "iam": Literal["ENABLED", "DISABLED"]},
+    {"accessPointId": str, "iam": EFSAuthorizationConfigIAM},
     total=False,
 )
 
@@ -284,7 +293,7 @@ _OptionalEFSVolumeConfigurationTypeDef = TypedDict(
     "_OptionalEFSVolumeConfigurationTypeDef",
     {
         "rootDirectory": str,
-        "transitEncryption": Literal["ENABLED", "DISABLED"],
+        "transitEncryption": EFSTransitEncryption,
         "transitEncryptionPort": int,
         "authorizationConfig": "EFSAuthorizationConfigTypeDef",
     },
@@ -309,7 +318,7 @@ class Ec2ConfigurationTypeDef(_RequiredEc2ConfigurationTypeDef, _OptionalEc2Conf
 
 
 _RequiredEvaluateOnExitTypeDef = TypedDict(
-    "_RequiredEvaluateOnExitTypeDef", {"action": Literal["RETRY", "EXIT"]}
+    "_RequiredEvaluateOnExitTypeDef", {"action": RetryAction}
 )
 _OptionalEvaluateOnExitTypeDef = TypedDict(
     "_OptionalEvaluateOnExitTypeDef",
@@ -343,7 +352,7 @@ _OptionalJobDefinitionTypeDef = TypedDict(
         "nodeProperties": "NodePropertiesTypeDef",
         "tags": Dict[str, str],
         "propagateTags": bool,
-        "platformCapabilities": List[Literal["EC2", "FARGATE"]],
+        "platformCapabilities": List[PlatformCapability],
     },
     total=False,
 )
@@ -354,7 +363,7 @@ class JobDefinitionTypeDef(_RequiredJobDefinitionTypeDef, _OptionalJobDefinition
 
 
 JobDependencyTypeDef = TypedDict(
-    "JobDependencyTypeDef", {"jobId": str, "type": Literal["N_TO_N", "SEQUENTIAL"]}, total=False
+    "JobDependencyTypeDef", {"jobId": str, "type": ArrayJobDependency}, total=False
 )
 
 _RequiredJobDetailTypeDef = TypedDict(
@@ -363,9 +372,7 @@ _RequiredJobDetailTypeDef = TypedDict(
         "jobName": str,
         "jobId": str,
         "jobQueue": str,
-        "status": Literal[
-            "SUBMITTED", "PENDING", "RUNNABLE", "STARTING", "RUNNING", "SUCCEEDED", "FAILED"
-        ],
+        "status": JobStatus,
         "startedAt": int,
         "jobDefinition": str,
     },
@@ -388,7 +395,7 @@ _OptionalJobDetailTypeDef = TypedDict(
         "timeout": "JobTimeoutTypeDef",
         "tags": Dict[str, str],
         "propagateTags": bool,
-        "platformCapabilities": List[Literal["EC2", "FARGATE"]],
+        "platformCapabilities": List[PlatformCapability],
     },
     total=False,
 )
@@ -403,18 +410,14 @@ _RequiredJobQueueDetailTypeDef = TypedDict(
     {
         "jobQueueName": str,
         "jobQueueArn": str,
-        "state": Literal["ENABLED", "DISABLED"],
+        "state": JQState,
         "priority": int,
         "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
     },
 )
 _OptionalJobQueueDetailTypeDef = TypedDict(
     "_OptionalJobQueueDetailTypeDef",
-    {
-        "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
-        "statusReason": str,
-        "tags": Dict[str, str],
-    },
+    {"status": JQStatus, "statusReason": str, "tags": Dict[str, str]},
     total=False,
 )
 
@@ -429,9 +432,7 @@ _OptionalJobSummaryTypeDef = TypedDict(
     {
         "jobArn": str,
         "createdAt": int,
-        "status": Literal[
-            "SUBMITTED", "PENDING", "RUNNABLE", "STARTING", "RUNNING", "SUCCEEDED", "FAILED"
-        ],
+        "status": JobStatus,
         "statusReason": str,
         "startedAt": int,
         "stoppedAt": int,
@@ -471,12 +472,7 @@ LinuxParametersTypeDef = TypedDict(
 )
 
 _RequiredLogConfigurationTypeDef = TypedDict(
-    "_RequiredLogConfigurationTypeDef",
-    {
-        "logDriver": Literal[
-            "json-file", "syslog", "journald", "gelf", "fluentd", "awslogs", "splunk"
-        ]
-    },
+    "_RequiredLogConfigurationTypeDef", {"logDriver": LogDriver}
 )
 _OptionalLogConfigurationTypeDef = TypedDict(
     "_OptionalLogConfigurationTypeDef",
@@ -494,7 +490,7 @@ MountPointTypeDef = TypedDict(
 )
 
 NetworkConfigurationTypeDef = TypedDict(
-    "NetworkConfigurationTypeDef", {"assignPublicIp": Literal["ENABLED", "DISABLED"]}, total=False
+    "NetworkConfigurationTypeDef", {"assignPublicIp": AssignPublicIp}, total=False
 )
 
 NetworkInterfaceTypeDef = TypedDict(
@@ -549,7 +545,7 @@ class NodeRangePropertyTypeDef(
 
 
 ResourceRequirementTypeDef = TypedDict(
-    "ResourceRequirementTypeDef", {"value": str, "type": Literal["GPU", "VCPU", "MEMORY"]}
+    "ResourceRequirementTypeDef", {"value": str, "type": ResourceType}
 )
 
 RetryStrategyTypeDef = TypedDict(
